# yapstone-so

Yapstone - the Ruby gem for the Yapstone Staged On-Boarding Services

Set of API's that allow clients to onboard with Yapstone.

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build yapstone-so.gemspec
```

Then either install the gem locally:

```shell
gem install ./yapstone-so-1.0.0.gem
```

(for development, run `gem install --dev ./yapstone-so-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'yapstone-so', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'yapstone-so', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'yapstone-so'

# Setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::AssetsApi.new
asset_request = Yapstone::AssetRequest.new # AssetRequest | The Asset Request Resource to be created.

begin
  result = api_instance.create_asset(asset_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling AssetsApi->create_asset: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Yapstone::AssetsApi* | [**create_asset**](docs/AssetsApi.md#create_asset) | **POST** /assets | 
*Yapstone::AssetsApi* | [**deactivate_asset**](docs/AssetsApi.md#deactivate_asset) | **DELETE** /assets/{assetId} | 
*Yapstone::AssetsApi* | [**get_asset**](docs/AssetsApi.md#get_asset) | **GET** /assets/{assetId} | 
*Yapstone::AssetsApi* | [**get_assets**](docs/AssetsApi.md#get_assets) | **GET** /assets | 
*Yapstone::AssetsApi* | [**update_asset**](docs/AssetsApi.md#update_asset) | **PUT** /assets/{assetId} | 
*Yapstone::AuthenticationApi* | [**authenticate_partner**](docs/AuthenticationApi.md#authenticate_partner) | **POST** /v1/oauth2/client_credential/accesstoken | Authenticate Partner
*Yapstone::BusinessApplicantsApi* | [**create_business_applicant**](docs/BusinessApplicantsApi.md#create_business_applicant) | **POST** /business-applicants | 
*Yapstone::BusinessApplicantsApi* | [**deactivate_business_applicant**](docs/BusinessApplicantsApi.md#deactivate_business_applicant) | **DELETE** /business-applicants/{applicantId} | 
*Yapstone::BusinessApplicantsApi* | [**get_business_applicant**](docs/BusinessApplicantsApi.md#get_business_applicant) | **GET** /business-applicants/{applicantId} | 
*Yapstone::BusinessApplicantsApi* | [**get_business_applicants**](docs/BusinessApplicantsApi.md#get_business_applicants) | **GET** /business-applicants | 
*Yapstone::BusinessApplicantsApi* | [**update_business_applicant**](docs/BusinessApplicantsApi.md#update_business_applicant) | **PUT** /business-applicants/{applicantId} | 
*Yapstone::ContractsApi* | [**create_contract**](docs/ContractsApi.md#create_contract) | **POST** /contracts | 
*Yapstone::ContractsApi* | [**get_all_contracts**](docs/ContractsApi.md#get_all_contracts) | **GET** /contracts | Retrieves all of contracts
*Yapstone::ContractsApi* | [**get_contract**](docs/ContractsApi.md#get_contract) | **GET** /contracts/{contractId} | 
*Yapstone::ContractsApi* | [**update_contract**](docs/ContractsApi.md#update_contract) | **PUT** /contracts/{contractId} | 
*Yapstone::IndividualApplicantsApi* | [**create_individual_applicant**](docs/IndividualApplicantsApi.md#create_individual_applicant) | **POST** /individual-applicants | 
*Yapstone::IndividualApplicantsApi* | [**deactivate_applicant**](docs/IndividualApplicantsApi.md#deactivate_applicant) | **DELETE** /individual-applicants/{applicantId} | 
*Yapstone::IndividualApplicantsApi* | [**get_individual_applicant**](docs/IndividualApplicantsApi.md#get_individual_applicant) | **GET** /individual-applicants/{applicantId} | 
*Yapstone::IndividualApplicantsApi* | [**get_individual_applicants**](docs/IndividualApplicantsApi.md#get_individual_applicants) | **GET** /individual-applicants | 
*Yapstone::IndividualApplicantsApi* | [**update_individual_applicant**](docs/IndividualApplicantsApi.md#update_individual_applicant) | **PUT** /individual-applicants/{applicantId} | 
*Yapstone::InstrumentsApi* | [**create_instrument**](docs/InstrumentsApi.md#create_instrument) | **POST** /instruments | 
*Yapstone::InstrumentsApi* | [**deactivate_instrument**](docs/InstrumentsApi.md#deactivate_instrument) | **DELETE** /instruments/{instrumentId} | 
*Yapstone::InstrumentsApi* | [**get_instrument**](docs/InstrumentsApi.md#get_instrument) | **GET** /instruments/{instrumentId} | 
*Yapstone::InstrumentsApi* | [**get_instruments**](docs/InstrumentsApi.md#get_instruments) | **GET** /instruments | 
*Yapstone::InstrumentsApi* | [**update_instrument**](docs/InstrumentsApi.md#update_instrument) | **PUT** /instruments/{instrumentId} | 
*Yapstone::MarketplaceProductsApi* | [**get_marketplace_product**](docs/MarketplaceProductsApi.md#get_marketplace_product) | **GET** /marketplace-products/{productId} | Retrieves a MarketPlace Product
*Yapstone::MarketplaceProductsApi* | [**update_marketplace_product**](docs/MarketplaceProductsApi.md#update_marketplace_product) | **PUT** /marketplace-products/{productId} | Update selctive MarketPlace Product details
*Yapstone::MarketplacesApi* | [**add_marketplace_product**](docs/MarketplacesApi.md#add_marketplace_product) | **POST** /contracts/{contractId}/marketplaces | 
*Yapstone::MarketplacesApi* | [**deactivate_marketplace_product**](docs/MarketplacesApi.md#deactivate_marketplace_product) | **DELETE** /contracts/{contractId}/marketplaces/{assetId} | 
*Yapstone::MarketplacesApi* | [**get_marketplace_product_by_asset_id**](docs/MarketplacesApi.md#get_marketplace_product_by_asset_id) | **GET** /contracts/{contractId}/marketplaces/{assetId} | 
*Yapstone::MarketplacesApi* | [**update_marketplace_product_by_contract_id**](docs/MarketplacesApi.md#update_marketplace_product_by_contract_id) | **PUT** /contracts/{contractId}/marketplaces/{assetId} | 
*Yapstone::PayoutInstrumentsApi* | [**create_payout_instrument**](docs/PayoutInstrumentsApi.md#create_payout_instrument) | **POST** /payout-instruments | 
*Yapstone::PayoutInstrumentsApi* | [**deactivate_payout_instrument**](docs/PayoutInstrumentsApi.md#deactivate_payout_instrument) | **DELETE** /payout-instruments/{payoutInstrumentId} | 
*Yapstone::PayoutInstrumentsApi* | [**get_payout_instrument**](docs/PayoutInstrumentsApi.md#get_payout_instrument) | **GET** /payout-instruments/{payoutInstrumentId} | 
*Yapstone::PayoutInstrumentsApi* | [**get_payout_instruments**](docs/PayoutInstrumentsApi.md#get_payout_instruments) | **GET** /payout-instruments | 
*Yapstone::PayoutInstrumentsApi* | [**update_payout_instrument**](docs/PayoutInstrumentsApi.md#update_payout_instrument) | **PUT** /payout-instruments/{payoutInstrumentId} | 
*Yapstone::PayoutProductsApi* | [**get_payout_product**](docs/PayoutProductsApi.md#get_payout_product) | **GET** /payout-products/{productId} | Retrieves a Payout Product
*Yapstone::PayoutsApi* | [**add_payout_product**](docs/PayoutsApi.md#add_payout_product) | **POST** /contracts/{contractId}/payouts | 
*Yapstone::PayoutsApi* | [**deactivate_payout_product**](docs/PayoutsApi.md#deactivate_payout_product) | **DELETE** /contracts/{contractId}/payouts/{payoutInstrumentId} | 
*Yapstone::PayoutsApi* | [**get_payout_product_by_instrument_id**](docs/PayoutsApi.md#get_payout_product_by_instrument_id) | **GET** /contracts/{contractId}/payouts/{payoutInstrumentId} | 
*Yapstone::PayoutsApi* | [**update_payout_product**](docs/PayoutsApi.md#update_payout_product) | **PUT** /contracts/{contractId}/payouts/{payoutInstrumentId} | 


## Documentation for Models

 - [Yapstone::AbstractEntity](docs/AbstractEntity.md)
 - [Yapstone::ActionResource](docs/ActionResource.md)
 - [Yapstone::ActionStatusResource](docs/ActionStatusResource.md)
 - [Yapstone::AddressResource](docs/AddressResource.md)
 - [Yapstone::ApplicantConsentRequest](docs/ApplicantConsentRequest.md)
 - [Yapstone::ApplicantConsentResource](docs/ApplicantConsentResource.md)
 - [Yapstone::ApplicantConsentType](docs/ApplicantConsentType.md)
 - [Yapstone::ApplicantResource](docs/ApplicantResource.md)
 - [Yapstone::AssetRequest](docs/AssetRequest.md)
 - [Yapstone::AssetRequestAllOf](docs/AssetRequestAllOf.md)
 - [Yapstone::AssetRequestCommon](docs/AssetRequestCommon.md)
 - [Yapstone::AssetResource](docs/AssetResource.md)
 - [Yapstone::AssetResourceAllOf](docs/AssetResourceAllOf.md)
 - [Yapstone::AssetUpdateRequest](docs/AssetUpdateRequest.md)
 - [Yapstone::AssetUpdateRequestAllOf](docs/AssetUpdateRequestAllOf.md)
 - [Yapstone::AssetsResource](docs/AssetsResource.md)
 - [Yapstone::AssetsResourceAllOf](docs/AssetsResourceAllOf.md)
 - [Yapstone::BankAccountDataResource](docs/BankAccountDataResource.md)
 - [Yapstone::BankAccountResource](docs/BankAccountResource.md)
 - [Yapstone::BeneficialOwnerRequest](docs/BeneficialOwnerRequest.md)
 - [Yapstone::BeneficialOwnerResource](docs/BeneficialOwnerResource.md)
 - [Yapstone::BeneficialOwnersPatch](docs/BeneficialOwnersPatch.md)
 - [Yapstone::BusinessApplicantAdminFieldsResource](docs/BusinessApplicantAdminFieldsResource.md)
 - [Yapstone::BusinessApplicantAdminResource](docs/BusinessApplicantAdminResource.md)
 - [Yapstone::BusinessApplicantRequest](docs/BusinessApplicantRequest.md)
 - [Yapstone::BusinessApplicantResource](docs/BusinessApplicantResource.md)
 - [Yapstone::BusinessApplicantResourceAllOf](docs/BusinessApplicantResourceAllOf.md)
 - [Yapstone::BusinessApplicantUpdateRequest](docs/BusinessApplicantUpdateRequest.md)
 - [Yapstone::BusinessApplicantsResource](docs/BusinessApplicantsResource.md)
 - [Yapstone::BusinessApplicantsResourceAllOf](docs/BusinessApplicantsResourceAllOf.md)
 - [Yapstone::BusinessIdType](docs/BusinessIdType.md)
 - [Yapstone::BusinessIdentificationResource](docs/BusinessIdentificationResource.md)
 - [Yapstone::BusinessOwnerResource](docs/BusinessOwnerResource.md)
 - [Yapstone::BusinessProfileResource](docs/BusinessProfileResource.md)
 - [Yapstone::BusinessUpdateIdentificationResource](docs/BusinessUpdateIdentificationResource.md)
 - [Yapstone::CapabilityResource](docs/CapabilityResource.md)
 - [Yapstone::CardDataResource](docs/CardDataResource.md)
 - [Yapstone::Consent](docs/Consent.md)
 - [Yapstone::ConsentRequest](docs/ConsentRequest.md)
 - [Yapstone::ConsentResource](docs/ConsentResource.md)
 - [Yapstone::ConsentType](docs/ConsentType.md)
 - [Yapstone::ContractCreateRequest](docs/ContractCreateRequest.md)
 - [Yapstone::ContractResource](docs/ContractResource.md)
 - [Yapstone::ContractResourceDTO](docs/ContractResourceDTO.md)
 - [Yapstone::ContractResourceDTOAllOf](docs/ContractResourceDTOAllOf.md)
 - [Yapstone::ContractUpdateRequest](docs/ContractUpdateRequest.md)
 - [Yapstone::CustomerHistoryResource](docs/CustomerHistoryResource.md)
 - [Yapstone::DeactivateRequest](docs/DeactivateRequest.md)
 - [Yapstone::DeactivateResponse](docs/DeactivateResponse.md)
 - [Yapstone::DirectDebitConsentResource](docs/DirectDebitConsentResource.md)
 - [Yapstone::DirectDebitFrequencyType](docs/DirectDebitFrequencyType.md)
 - [Yapstone::DirectDebitSchemeType](docs/DirectDebitSchemeType.md)
 - [Yapstone::DirectDebtCapabilityResource](docs/DirectDebtCapabilityResource.md)
 - [Yapstone::EntitiesResource](docs/EntitiesResource.md)
 - [Yapstone::EntityHistoryResource](docs/EntityHistoryResource.md)
 - [Yapstone::EntityProductStatusResource](docs/EntityProductStatusResource.md)
 - [Yapstone::EntityUpdateEvent](docs/EntityUpdateEvent.md)
 - [Yapstone::EntityUpdatedAttribute](docs/EntityUpdatedAttribute.md)
 - [Yapstone::Errors](docs/Errors.md)
 - [Yapstone::ExpirationDateResource](docs/ExpirationDateResource.md)
 - [Yapstone::Gender](docs/Gender.md)
 - [Yapstone::GovIdentificationResource](docs/GovIdentificationResource.md)
 - [Yapstone::GovIdentificationUpdateResource](docs/GovIdentificationUpdateResource.md)
 - [Yapstone::GovernmentIdType](docs/GovernmentIdType.md)
 - [Yapstone::IndividualApplicantAdminFieldsResource](docs/IndividualApplicantAdminFieldsResource.md)
 - [Yapstone::IndividualApplicantAdminResource](docs/IndividualApplicantAdminResource.md)
 - [Yapstone::IndividualApplicantRequest](docs/IndividualApplicantRequest.md)
 - [Yapstone::IndividualApplicantResource](docs/IndividualApplicantResource.md)
 - [Yapstone::IndividualApplicantUpdateRequest](docs/IndividualApplicantUpdateRequest.md)
 - [Yapstone::IndividualApplicantsResource](docs/IndividualApplicantsResource.md)
 - [Yapstone::IndividualApplicantsResourceAllOf](docs/IndividualApplicantsResourceAllOf.md)
 - [Yapstone::IndividualOwnerResource](docs/IndividualOwnerResource.md)
 - [Yapstone::InlineResponse200](docs/InlineResponse200.md)
 - [Yapstone::IssuerScope](docs/IssuerScope.md)
 - [Yapstone::MarketPlaceApplicantResource](docs/MarketPlaceApplicantResource.md)
 - [Yapstone::MarketPlacePropertyResource](docs/MarketPlacePropertyResource.md)
 - [Yapstone::MarketplaceProductAdd](docs/MarketplaceProductAdd.md)
 - [Yapstone::MarketplaceProductBasic](docs/MarketplaceProductBasic.md)
 - [Yapstone::MarketplaceProductExtra](docs/MarketplaceProductExtra.md)
 - [Yapstone::MarketplaceProductExtraAllOf](docs/MarketplaceProductExtraAllOf.md)
 - [Yapstone::MarketplaceProductPayoutInstrumentResource](docs/MarketplaceProductPayoutInstrumentResource.md)
 - [Yapstone::MarketplaceProductPayoutInstrumentUpdate](docs/MarketplaceProductPayoutInstrumentUpdate.md)
 - [Yapstone::MarketplaceProductResource](docs/MarketplaceProductResource.md)
 - [Yapstone::MarketplaceProductSubResource](docs/MarketplaceProductSubResource.md)
 - [Yapstone::MarketplaceProductUpdate](docs/MarketplaceProductUpdate.md)
 - [Yapstone::Meta](docs/Meta.md)
 - [Yapstone::MoneyResource](docs/MoneyResource.md)
 - [Yapstone::NameResource](docs/NameResource.md)
 - [Yapstone::OwnerRequest](docs/OwnerRequest.md)
 - [Yapstone::OwnerResource](docs/OwnerResource.md)
 - [Yapstone::Pagination](docs/Pagination.md)
 - [Yapstone::PatchOperation](docs/PatchOperation.md)
 - [Yapstone::PayoutInstrumentRequest](docs/PayoutInstrumentRequest.md)
 - [Yapstone::PayoutInstrumentResource](docs/PayoutInstrumentResource.md)
 - [Yapstone::PayoutInstrumentResourceCommonEntities](docs/PayoutInstrumentResourceCommonEntities.md)
 - [Yapstone::PayoutInstrumentUpdateRequest](docs/PayoutInstrumentUpdateRequest.md)
 - [Yapstone::PayoutInstrumentsResource](docs/PayoutInstrumentsResource.md)
 - [Yapstone::PayoutInstrumentsResourceAllOf](docs/PayoutInstrumentsResourceAllOf.md)
 - [Yapstone::PayoutProductAdd](docs/PayoutProductAdd.md)
 - [Yapstone::PayoutProductResource](docs/PayoutProductResource.md)
 - [Yapstone::PayoutProductSubResource](docs/PayoutProductSubResource.md)
 - [Yapstone::PayoutProductSubResourceAllOf](docs/PayoutProductSubResourceAllOf.md)
 - [Yapstone::PhoneResource](docs/PhoneResource.md)
 - [Yapstone::PriceSettingResource](docs/PriceSettingResource.md)
 - [Yapstone::PrimaryContactResource](docs/PrimaryContactResource.md)
 - [Yapstone::Product](docs/Product.md)
 - [Yapstone::ProductRead](docs/ProductRead.md)
 - [Yapstone::ProductWrite](docs/ProductWrite.md)
 - [Yapstone::ProfileResource](docs/ProfileResource.md)
 - [Yapstone::PropertyHistoryResource](docs/PropertyHistoryResource.md)
 - [Yapstone::PropertyInfoResource](docs/PropertyInfoResource.md)
 - [Yapstone::PropertyOwnerResource](docs/PropertyOwnerResource.md)
 - [Yapstone::PropertyResource](docs/PropertyResource.md)
 - [Yapstone::PropertyTrackerResource](docs/PropertyTrackerResource.md)
 - [Yapstone::RegistrationResource](docs/RegistrationResource.md)
 - [Yapstone::ReservationSettingResource](docs/ReservationSettingResource.md)
 - [Yapstone::Resource](docs/Resource.md)
 - [Yapstone::SocialNetworkResource](docs/SocialNetworkResource.md)
 - [Yapstone::StatusReasonResource](docs/StatusReasonResource.md)
 - [Yapstone::StatusRequest](docs/StatusRequest.md)
 - [Yapstone::StatusResource](docs/StatusResource.md)
 - [Yapstone::StaySettingResource](docs/StaySettingResource.md)
 - [Yapstone::SuspensionReasonResource](docs/SuspensionReasonResource.md)
 - [Yapstone::TravelerResource](docs/TravelerResource.md)


## Documentation for Authorization


### Bearer

- **Type**: Bearer authentication (JWT)

