# Yapstone::AssetsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_asset**](AssetsApi.md#create_asset) | **POST** /assets | 
[**deactivate_asset**](AssetsApi.md#deactivate_asset) | **DELETE** /assets/{assetId} | 
[**get_asset**](AssetsApi.md#get_asset) | **GET** /assets/{assetId} | 
[**get_assets**](AssetsApi.md#get_assets) | **GET** /assets | 
[**update_asset**](AssetsApi.md#update_asset) | **PUT** /assets/{assetId} | 



## create_asset

> AssetResource create_asset(asset_request)



Creates an Asset Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::AssetsApi.new
asset_request = Yapstone::AssetRequest.new # AssetRequest | The Asset Request Resource to be created.

begin
  result = api_instance.create_asset(asset_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling AssetsApi->create_asset: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **asset_request** | [**AssetRequest**](AssetRequest.md)| The Asset Request Resource to be created. | 

### Return type

[**AssetResource**](AssetResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deactivate_asset

> DeactivateResponse deactivate_asset(asset_id)



Deactivates the Asset Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::AssetsApi.new
asset_id = 'asset_id_example' # String | The unique id of the Asset Resource.

begin
  result = api_instance.deactivate_asset(asset_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling AssetsApi->deactivate_asset: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **asset_id** | **String**| The unique id of the Asset Resource. | 

### Return type

[**DeactivateResponse**](DeactivateResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_asset

> AssetResource get_asset(asset_id)



Retrieves an Asset Resource from the system for the given assetId.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::AssetsApi.new
asset_id = 'asset_id_example' # String | The unique id of the Asset Resource.

begin
  result = api_instance.get_asset(asset_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling AssetsApi->get_asset: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **asset_id** | **String**| The unique id of the Asset Resource. | 

### Return type

[**AssetResource**](AssetResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_assets

> AssetsResource get_assets(opts)



Get Asset Resources the actor has access to in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::AssetsApi.new
opts = {
  page: 56, # Integer | page number
  size: 56, # Integer | Maximum number of records to return per page
  external_id: 'external_id_example' # String | The identifier used by an external client.
}

begin
  result = api_instance.get_assets(opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling AssetsApi->get_assets: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | **Integer**| page number | [optional] 
 **size** | **Integer**| Maximum number of records to return per page | [optional] 
 **external_id** | **String**| The identifier used by an external client. | [optional] 

### Return type

[**AssetsResource**](AssetsResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_asset

> AssetResource update_asset(asset_id, asset_update_request)



Updates the Asset Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::AssetsApi.new
asset_id = 'asset_id_example' # String | The unique id of the Asset Resource.
asset_update_request = Yapstone::AssetUpdateRequest.new # AssetUpdateRequest | The Asset Request Resource to be created.

begin
  result = api_instance.update_asset(asset_id, asset_update_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling AssetsApi->update_asset: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **asset_id** | **String**| The unique id of the Asset Resource. | 
 **asset_update_request** | [**AssetUpdateRequest**](AssetUpdateRequest.md)| The Asset Request Resource to be created. | 

### Return type

[**AssetResource**](AssetResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json-patch+json
- **Accept**: application/json

