# Yapstone::BusinessApplicantsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_business_applicant**](BusinessApplicantsApi.md#create_business_applicant) | **POST** /business-applicants | 
[**deactivate_business_applicant**](BusinessApplicantsApi.md#deactivate_business_applicant) | **DELETE** /business-applicants/{applicantId} | 
[**get_business_applicant**](BusinessApplicantsApi.md#get_business_applicant) | **GET** /business-applicants/{applicantId} | 
[**get_business_applicants**](BusinessApplicantsApi.md#get_business_applicants) | **GET** /business-applicants | 
[**update_business_applicant**](BusinessApplicantsApi.md#update_business_applicant) | **PUT** /business-applicants/{applicantId} | 



## create_business_applicant

> BusinessApplicantResource create_business_applicant(business_applicant_request)



Creates a Business Applicant Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::BusinessApplicantsApi.new
business_applicant_request = Yapstone::BusinessApplicantRequest.new # BusinessApplicantRequest | The Business Applicant Resource to be created.

begin
  result = api_instance.create_business_applicant(business_applicant_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling BusinessApplicantsApi->create_business_applicant: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **business_applicant_request** | [**BusinessApplicantRequest**](BusinessApplicantRequest.md)| The Business Applicant Resource to be created. | 

### Return type

[**BusinessApplicantResource**](BusinessApplicantResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deactivate_business_applicant

> DeactivateResponse deactivate_business_applicant(applicant_id)



Deactivates the Business Applicant Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::BusinessApplicantsApi.new
applicant_id = 'applicant_id_example' # String | The unique id of the Applicant Resource.

begin
  result = api_instance.deactivate_business_applicant(applicant_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling BusinessApplicantsApi->deactivate_business_applicant: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **applicant_id** | **String**| The unique id of the Applicant Resource. | 

### Return type

[**DeactivateResponse**](DeactivateResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_business_applicant

> BusinessApplicantResource get_business_applicant(applicant_id)



Retrieves an Business Applicant Resource from the system for the given applicantId.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::BusinessApplicantsApi.new
applicant_id = 'applicant_id_example' # String | The unique id of the Business Applicant Resource.

begin
  result = api_instance.get_business_applicant(applicant_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling BusinessApplicantsApi->get_business_applicant: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **applicant_id** | **String**| The unique id of the Business Applicant Resource. | 

### Return type

[**BusinessApplicantResource**](BusinessApplicantResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_business_applicants

> BusinessApplicantsResource get_business_applicants(external_id, opts)



Get all Business Applicant Resources the actor has access to in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::BusinessApplicantsApi.new
external_id = 'external_id_example' # String | The identifier used by an external client.
opts = {
  page: 56, # Integer | page number
  size: 56 # Integer | Maximum number of records to return per page
}

begin
  result = api_instance.get_business_applicants(external_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling BusinessApplicantsApi->get_business_applicants: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **external_id** | **String**| The identifier used by an external client. | 
 **page** | **Integer**| page number | [optional] 
 **size** | **Integer**| Maximum number of records to return per page | [optional] 

### Return type

[**BusinessApplicantsResource**](BusinessApplicantsResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_business_applicant

> BusinessApplicantResource update_business_applicant(applicant_id, business_applicant_update_request)



Updates the Business Applicant Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::BusinessApplicantsApi.new
applicant_id = 'applicant_id_example' # String | The unique id of the BusinessApplicant Resource.
business_applicant_update_request = Yapstone::BusinessApplicantUpdateRequest.new # BusinessApplicantUpdateRequest | The Business Applicant Resource to be created after updation.

begin
  result = api_instance.update_business_applicant(applicant_id, business_applicant_update_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling BusinessApplicantsApi->update_business_applicant: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **applicant_id** | **String**| The unique id of the BusinessApplicant Resource. | 
 **business_applicant_update_request** | [**BusinessApplicantUpdateRequest**](BusinessApplicantUpdateRequest.md)| The Business Applicant Resource to be created after updation. | 

### Return type

[**BusinessApplicantResource**](BusinessApplicantResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json-patch+json
- **Accept**: application/json

