# Yapstone::ContractsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_contract**](ContractsApi.md#create_contract) | **POST** /contracts | 
[**get_all_contracts**](ContractsApi.md#get_all_contracts) | **GET** /contracts | Retrieves all of contracts
[**get_contract**](ContractsApi.md#get_contract) | **GET** /contracts/{contractId} | 
[**update_contract**](ContractsApi.md#update_contract) | **PUT** /contracts/{contractId} | 



## create_contract

> ContractResource create_contract(contract_create_request)



Creates an Contract Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::ContractsApi.new
contract_create_request = Yapstone::ContractCreateRequest.new # ContractCreateRequest | The Contract Request Resource to be created.

begin
  result = api_instance.create_contract(contract_create_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling ContractsApi->create_contract: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_create_request** | [**ContractCreateRequest**](ContractCreateRequest.md)| The Contract Request Resource to be created. | 

### Return type

[**ContractResource**](ContractResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_all_contracts

> ContractResourceDTO get_all_contracts(opts)

Retrieves all of contracts

Retrieves all of the Contracts

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::ContractsApi.new
opts = {
  applicant_id: 'applicant_id_example', # String | applicantId
  asset_id: 'asset_id_example', # String | assetId
  payout_instrument_id: 'payout_instrument_id_example', # String | payoutInstrumentId
  product: 'product_example' # String | filter by provided product
}

begin
  #Retrieves all of contracts
  result = api_instance.get_all_contracts(opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling ContractsApi->get_all_contracts: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **applicant_id** | **String**| applicantId | [optional] 
 **asset_id** | **String**| assetId | [optional] 
 **payout_instrument_id** | **String**| payoutInstrumentId | [optional] 
 **product** | **String**| filter by provided product | [optional] 

### Return type

[**ContractResourceDTO**](ContractResourceDTO.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_contract

> ContractResource get_contract(contract_id)



Retrieves an Contract Resource from the system for the given contractId.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::ContractsApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.

begin
  result = api_instance.get_contract(contract_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling ContractsApi->get_contract: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 

### Return type

[**ContractResource**](ContractResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_contract

> ContractResource update_contract(contract_id, contract_update_request)



Updates the Contract Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::ContractsApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
contract_update_request = Yapstone::ContractUpdateRequest.new # ContractUpdateRequest | The Contract Resource to be created after updation.

begin
  result = api_instance.update_contract(contract_id, contract_update_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling ContractsApi->update_contract: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **contract_update_request** | [**ContractUpdateRequest**](ContractUpdateRequest.md)| The Contract Resource to be created after updation. | 

### Return type

[**ContractResource**](ContractResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json-patch+json
- **Accept**: application/json

