# Yapstone::IndividualApplicantsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_individual_applicant**](IndividualApplicantsApi.md#create_individual_applicant) | **POST** /individual-applicants | 
[**deactivate_applicant**](IndividualApplicantsApi.md#deactivate_applicant) | **DELETE** /individual-applicants/{applicantId} | 
[**get_individual_applicant**](IndividualApplicantsApi.md#get_individual_applicant) | **GET** /individual-applicants/{applicantId} | 
[**get_individual_applicants**](IndividualApplicantsApi.md#get_individual_applicants) | **GET** /individual-applicants | 
[**update_individual_applicant**](IndividualApplicantsApi.md#update_individual_applicant) | **PUT** /individual-applicants/{applicantId} | 



## create_individual_applicant

> IndividualApplicantResource create_individual_applicant(individual_applicant_request)



Creates an Applicant Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::IndividualApplicantsApi.new
individual_applicant_request = Yapstone::IndividualApplicantRequest.new # IndividualApplicantRequest | The Applicant Resource to be created.

begin
  result = api_instance.create_individual_applicant(individual_applicant_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling IndividualApplicantsApi->create_individual_applicant: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **individual_applicant_request** | [**IndividualApplicantRequest**](IndividualApplicantRequest.md)| The Applicant Resource to be created. | 

### Return type

[**IndividualApplicantResource**](IndividualApplicantResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deactivate_applicant

> DeactivateResponse deactivate_applicant(applicant_id)



Deactivates the Individual Applicant Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::IndividualApplicantsApi.new
applicant_id = 'applicant_id_example' # String | The unique id of the Individual Applicant Resource.

begin
  result = api_instance.deactivate_applicant(applicant_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling IndividualApplicantsApi->deactivate_applicant: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **applicant_id** | **String**| The unique id of the Individual Applicant Resource. | 

### Return type

[**DeactivateResponse**](DeactivateResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_individual_applicant

> IndividualApplicantResource get_individual_applicant(applicant_id)



Retrieves an Individual Applicant Resource from the system for the given applicantId.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::IndividualApplicantsApi.new
applicant_id = 'applicant_id_example' # String | The unique id of the Individual Applicant Resource.

begin
  result = api_instance.get_individual_applicant(applicant_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling IndividualApplicantsApi->get_individual_applicant: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **applicant_id** | **String**| The unique id of the Individual Applicant Resource. | 

### Return type

[**IndividualApplicantResource**](IndividualApplicantResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_individual_applicants

> IndividualApplicantsResource get_individual_applicants(external_id, opts)



Get all Individual Applicant Resources the actor has access to in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::IndividualApplicantsApi.new
external_id = 'external_id_example' # String | The identifier used by an external client.
opts = {
  page: 56, # Integer | page number
  size: 56 # Integer | Maximum number of records to return per page
}

begin
  result = api_instance.get_individual_applicants(external_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling IndividualApplicantsApi->get_individual_applicants: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **external_id** | **String**| The identifier used by an external client. | 
 **page** | **Integer**| page number | [optional] 
 **size** | **Integer**| Maximum number of records to return per page | [optional] 

### Return type

[**IndividualApplicantsResource**](IndividualApplicantsResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_individual_applicant

> IndividualApplicantResource update_individual_applicant(applicant_id, individual_applicant_update_request)



Updates the Individual Applicant Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::IndividualApplicantsApi.new
applicant_id = 'applicant_id_example' # String | The unique id of the Individual Applicant Resource.
individual_applicant_update_request = Yapstone::IndividualApplicantUpdateRequest.new # IndividualApplicantUpdateRequest | The Applicant Request Resource to be updated.

begin
  result = api_instance.update_individual_applicant(applicant_id, individual_applicant_update_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling IndividualApplicantsApi->update_individual_applicant: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **applicant_id** | **String**| The unique id of the Individual Applicant Resource. | 
 **individual_applicant_update_request** | [**IndividualApplicantUpdateRequest**](IndividualApplicantUpdateRequest.md)| The Applicant Request Resource to be updated. | 

### Return type

[**IndividualApplicantResource**](IndividualApplicantResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json-patch+json
- **Accept**: application/json

