# Yapstone::InstrumentsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_instrument**](InstrumentsApi.md#create_instrument) | **POST** /instruments | 
[**deactivate_instrument**](InstrumentsApi.md#deactivate_instrument) | **DELETE** /instruments/{instrumentId} | 
[**get_instrument**](InstrumentsApi.md#get_instrument) | **GET** /instruments/{instrumentId} | 
[**get_instruments**](InstrumentsApi.md#get_instruments) | **GET** /instruments | 
[**update_instrument**](InstrumentsApi.md#update_instrument) | **PUT** /instruments/{instrumentId} | 



## create_instrument

> PayoutInstrumentResource create_instrument(payout_instrument_request)



Creates an Payout Instrument Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::InstrumentsApi.new
payout_instrument_request = Yapstone::PayoutInstrumentRequest.new # PayoutInstrumentRequest | The Payout Instrument Request Resource to be created.

begin
  result = api_instance.create_instrument(payout_instrument_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling InstrumentsApi->create_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **payout_instrument_request** | [**PayoutInstrumentRequest**](PayoutInstrumentRequest.md)| The Payout Instrument Request Resource to be created. | 

### Return type

[**PayoutInstrumentResource**](PayoutInstrumentResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deactivate_instrument

> DeactivateResponse deactivate_instrument(instrument_id)



Deactivates the Payout Instrument Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::InstrumentsApi.new
instrument_id = 'instrument_id_example' # String | The unique id of the Instrument Resource.

begin
  result = api_instance.deactivate_instrument(instrument_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling InstrumentsApi->deactivate_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **instrument_id** | **String**| The unique id of the Instrument Resource. | 

### Return type

[**DeactivateResponse**](DeactivateResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_instrument

> PayoutInstrumentResource get_instrument(instrument_id)



Retrieves an Payout Instrument Resource from the system for the given payoutInstrumentId.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::InstrumentsApi.new
instrument_id = 'instrument_id_example' # String | The unique id of the Instrument Resource.

begin
  result = api_instance.get_instrument(instrument_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling InstrumentsApi->get_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **instrument_id** | **String**| The unique id of the Instrument Resource. | 

### Return type

[**PayoutInstrumentResource**](PayoutInstrumentResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_instruments

> PayoutInstrumentsResource get_instruments(opts)



Get all Payout Instrument Resources the actor has access to in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::InstrumentsApi.new
opts = {
  page: 56, # Integer | page number
  size: 56 # Integer | Maximum number of records to return per page
}

begin
  result = api_instance.get_instruments(opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling InstrumentsApi->get_instruments: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | **Integer**| page number | [optional] 
 **size** | **Integer**| Maximum number of records to return per page | [optional] 

### Return type

[**PayoutInstrumentsResource**](PayoutInstrumentsResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_instrument

> PayoutInstrumentResource update_instrument(instrument_id, payout_instrument_update_request)



Updates the PayoutInstrument Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::InstrumentsApi.new
instrument_id = 'instrument_id_example' # String | The unique id of the Instrument Resource.
payout_instrument_update_request = Yapstone::PayoutInstrumentUpdateRequest.new # PayoutInstrumentUpdateRequest | The PayoutInstrument Request Resource to be updated.

begin
  result = api_instance.update_instrument(instrument_id, payout_instrument_update_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling InstrumentsApi->update_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **instrument_id** | **String**| The unique id of the Instrument Resource. | 
 **payout_instrument_update_request** | [**PayoutInstrumentUpdateRequest**](PayoutInstrumentUpdateRequest.md)| The PayoutInstrument Request Resource to be updated. | 

### Return type

[**PayoutInstrumentResource**](PayoutInstrumentResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json-patch+json
- **Accept**: application/json

