# Yapstone::MarketplacesApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Method | HTTP request | Description
------------- | ------------- | -------------
[**add_marketplace_product**](MarketplacesApi.md#add_marketplace_product) | **POST** /contracts/{contractId}/marketplaces | 
[**deactivate_marketplace_product**](MarketplacesApi.md#deactivate_marketplace_product) | **DELETE** /contracts/{contractId}/marketplaces/{assetId} | 
[**get_marketplace_product_by_asset_id**](MarketplacesApi.md#get_marketplace_product_by_asset_id) | **GET** /contracts/{contractId}/marketplaces/{assetId} | 
[**update_marketplace_product_by_contract_id**](MarketplacesApi.md#update_marketplace_product_by_contract_id) | **PUT** /contracts/{contractId}/marketplaces/{assetId} | 



## add_marketplace_product

> MarketplaceProductResource add_marketplace_product(contract_id, marketplace_product_add)



Add a new market place in a given contract.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::MarketplacesApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
marketplace_product_add = Yapstone::MarketplaceProductAdd.new # MarketplaceProductAdd | The market place details

begin
  result = api_instance.add_marketplace_product(contract_id, marketplace_product_add)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling MarketplacesApi->add_marketplace_product: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **marketplace_product_add** | [**MarketplaceProductAdd**](MarketplaceProductAdd.md)| The market place details | 

### Return type

[**MarketplaceProductResource**](MarketplaceProductResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deactivate_marketplace_product

> deactivate_marketplace_product(contract_id, asset_id, deactivate_request)



deactivate the Marketplace Product Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::MarketplacesApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
asset_id = 'asset_id_example' # String | The unique id of the Asset Resource.
deactivate_request = Yapstone::DeactivateRequest.new # DeactivateRequest | The details of the deactivation process.

begin
  api_instance.deactivate_marketplace_product(contract_id, asset_id, deactivate_request)
rescue Yapstone::ApiError => e
  puts "Exception when calling MarketplacesApi->deactivate_marketplace_product: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **asset_id** | **String**| The unique id of the Asset Resource. | 
 **deactivate_request** | [**DeactivateRequest**](DeactivateRequest.md)| The details of the deactivation process. | 

### Return type

nil (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_marketplace_product_by_asset_id

> MarketplaceProductResource get_marketplace_product_by_asset_id(contract_id, asset_id)



Retrieves an Marketplace Resource from the system for the given contractId and assetId.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::MarketplacesApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
asset_id = 'asset_id_example' # String | The unique id of the Asset Resource.

begin
  result = api_instance.get_marketplace_product_by_asset_id(contract_id, asset_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling MarketplacesApi->get_marketplace_product_by_asset_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **asset_id** | **String**| The unique id of the Asset Resource. | 

### Return type

[**MarketplaceProductResource**](MarketplaceProductResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_marketplace_product_by_contract_id

> MarketplaceProductResource update_marketplace_product_by_contract_id(contract_id, asset_id, marketplace_product_update)



Updates the Marketplace Resource in a given Contract Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::MarketplacesApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
asset_id = 'asset_id_example' # String | The unique id of the Asset Resource.
marketplace_product_update = Yapstone::MarketplaceProductUpdate.new # MarketplaceProductUpdate | The Market Resource to be updated.

begin
  result = api_instance.update_marketplace_product_by_contract_id(contract_id, asset_id, marketplace_product_update)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling MarketplacesApi->update_marketplace_product_by_contract_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **asset_id** | **String**| The unique id of the Asset Resource. | 
 **marketplace_product_update** | [**MarketplaceProductUpdate**](MarketplaceProductUpdate.md)| The Market Resource to be updated. | 

### Return type

[**MarketplaceProductResource**](MarketplaceProductResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json-patch+json
- **Accept**: application/json

