# Yapstone::PayoutInstrumentsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_payout_instrument**](PayoutInstrumentsApi.md#create_payout_instrument) | **POST** /payout-instruments | 
[**deactivate_payout_instrument**](PayoutInstrumentsApi.md#deactivate_payout_instrument) | **DELETE** /payout-instruments/{payoutInstrumentId} | 
[**get_payout_instrument**](PayoutInstrumentsApi.md#get_payout_instrument) | **GET** /payout-instruments/{payoutInstrumentId} | 
[**get_payout_instruments**](PayoutInstrumentsApi.md#get_payout_instruments) | **GET** /payout-instruments | 
[**update_payout_instrument**](PayoutInstrumentsApi.md#update_payout_instrument) | **PUT** /payout-instruments/{payoutInstrumentId} | 



## create_payout_instrument

> PayoutInstrumentResource create_payout_instrument(payout_instrument_request)



Creates an Payout Instrument Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutInstrumentsApi.new
payout_instrument_request = Yapstone::PayoutInstrumentRequest.new # PayoutInstrumentRequest | The Payout Instrument Request Resource to be created.

begin
  result = api_instance.create_payout_instrument(payout_instrument_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutInstrumentsApi->create_payout_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **payout_instrument_request** | [**PayoutInstrumentRequest**](PayoutInstrumentRequest.md)| The Payout Instrument Request Resource to be created. | 

### Return type

[**PayoutInstrumentResource**](PayoutInstrumentResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deactivate_payout_instrument

> DeactivateResponse deactivate_payout_instrument(payout_instrument_id)



Deactivates the Payout Instrument Resource in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutInstrumentsApi.new
payout_instrument_id = 'payout_instrument_id_example' # String | The unique id of the  Payout Instrument Resource.

begin
  result = api_instance.deactivate_payout_instrument(payout_instrument_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutInstrumentsApi->deactivate_payout_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **payout_instrument_id** | **String**| The unique id of the  Payout Instrument Resource. | 

### Return type

[**DeactivateResponse**](DeactivateResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_payout_instrument

> PayoutInstrumentResource get_payout_instrument(payout_instrument_id)



Retrieves an Payout Instrument Resource from the system for the given payoutInstrumentId.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutInstrumentsApi.new
payout_instrument_id = 'payout_instrument_id_example' # String | The unique id of the  Payout Instrument Resource.

begin
  result = api_instance.get_payout_instrument(payout_instrument_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutInstrumentsApi->get_payout_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **payout_instrument_id** | **String**| The unique id of the  Payout Instrument Resource. | 

### Return type

[**PayoutInstrumentResource**](PayoutInstrumentResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_payout_instruments

> PayoutInstrumentsResource get_payout_instruments(opts)



Get all Payout Instrument Resources the actor has access to in the system.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutInstrumentsApi.new
opts = {
  page: 56, # Integer | page number
  size: 56 # Integer | Maximum number of records to return per page
}

begin
  result = api_instance.get_payout_instruments(opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutInstrumentsApi->get_payout_instruments: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | **Integer**| page number | [optional] 
 **size** | **Integer**| Maximum number of records to return per page | [optional] 

### Return type

[**PayoutInstrumentsResource**](PayoutInstrumentsResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_payout_instrument

> PayoutInstrumentResource update_payout_instrument(payout_instrument_id, payout_instrument_update_request)



Updates the PayoutInstrument Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutInstrumentsApi.new
payout_instrument_id = 'payout_instrument_id_example' # String | The unique id of the  Payout Instrument Resource.
payout_instrument_update_request = Yapstone::PayoutInstrumentUpdateRequest.new # PayoutInstrumentUpdateRequest | The PayoutInstrument Request Resource to be updated.

begin
  result = api_instance.update_payout_instrument(payout_instrument_id, payout_instrument_update_request)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutInstrumentsApi->update_payout_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **payout_instrument_id** | **String**| The unique id of the  Payout Instrument Resource. | 
 **payout_instrument_update_request** | [**PayoutInstrumentUpdateRequest**](PayoutInstrumentUpdateRequest.md)| The PayoutInstrument Request Resource to be updated. | 

### Return type

[**PayoutInstrumentResource**](PayoutInstrumentResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json-patch+json
- **Accept**: application/json

