# Yapstone::PayoutsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v2/onboarding*

Method | HTTP request | Description
------------- | ------------- | -------------
[**add_payout_product**](PayoutsApi.md#add_payout_product) | **POST** /contracts/{contractId}/payouts | 
[**deactivate_payout_product**](PayoutsApi.md#deactivate_payout_product) | **DELETE** /contracts/{contractId}/payouts/{payoutInstrumentId} | 
[**get_payout_product_by_instrument_id**](PayoutsApi.md#get_payout_product_by_instrument_id) | **GET** /contracts/{contractId}/payouts/{payoutInstrumentId} | 
[**update_payout_product**](PayoutsApi.md#update_payout_product) | **PUT** /contracts/{contractId}/payouts/{payoutInstrumentId} | 



## add_payout_product

> PayoutProductResource add_payout_product(contract_id, payout_product_add)



Add a payout product in a given contract.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutsApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
payout_product_add = Yapstone::PayoutProductAdd.new # PayoutProductAdd | The payout instruments list

begin
  result = api_instance.add_payout_product(contract_id, payout_product_add)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutsApi->add_payout_product: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **payout_product_add** | [**PayoutProductAdd**](PayoutProductAdd.md)| The payout instruments list | 

### Return type

[**PayoutProductResource**](PayoutProductResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deactivate_payout_product

> deactivate_payout_product(contract_id, payout_instrument_id, deactivate_request)



deactivate the Payout Product Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutsApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
payout_instrument_id = 'payout_instrument_id_example' # String | The unique id of the  Payout Instrument Resource.
deactivate_request = Yapstone::DeactivateRequest.new # DeactivateRequest | The details of the deactivation process.

begin
  api_instance.deactivate_payout_product(contract_id, payout_instrument_id, deactivate_request)
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutsApi->deactivate_payout_product: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **payout_instrument_id** | **String**| The unique id of the  Payout Instrument Resource. | 
 **deactivate_request** | [**DeactivateRequest**](DeactivateRequest.md)| The details of the deactivation process. | 

### Return type

nil (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_payout_product_by_instrument_id

> PayoutProductResource get_payout_product_by_instrument_id(contract_id, payout_instrument_id)



Retrieves an Payout Resource from the system for the given contractId and payoutInstrumentId.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutsApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
payout_instrument_id = 'payout_instrument_id_example' # String | The unique id of the  Payout Instrument Resource.

begin
  result = api_instance.get_payout_product_by_instrument_id(contract_id, payout_instrument_id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutsApi->get_payout_product_by_instrument_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **payout_instrument_id** | **String**| The unique id of the  Payout Instrument Resource. | 

### Return type

[**PayoutProductResource**](PayoutProductResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_payout_product

> PayoutProductResource update_payout_product(contract_id, payout_instrument_id, payout_product_resource)



Updates the Payout product in the Contract Resource.

### Example

```ruby
# load the gem
require 'yapstone-so'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PayoutsApi.new
contract_id = 'contract_id_example' # String | The unique id of the Contract Resource.
payout_instrument_id = 'payout_instrument_id_example' # String | The unique id of the  Payout Instrument Resource.
payout_product_resource = Yapstone::PayoutProductResource.new # PayoutProductResource | The Payout Resource to be updated.

begin
  result = api_instance.update_payout_product(contract_id, payout_instrument_id, payout_product_resource)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PayoutsApi->update_payout_product: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contract_id** | **String**| The unique id of the Contract Resource. | 
 **payout_instrument_id** | **String**| The unique id of the  Payout Instrument Resource. | 
 **payout_product_resource** | [**PayoutProductResource**](PayoutProductResource.md)| The Payout Resource to be updated. | 

### Return type

[**PayoutProductResource**](PayoutProductResource.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json-patch+json
- **Accept**: application/json

